@@ -12,7 +12,7 @@ use URI;
 
 use parent qw(Perinci::Access::Base);
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 my @logging_methods = Log::Any->logging_methods();
 
@@ -112,11 +112,11 @@ sub request {
         return [400, "Can't encode request as JSON: $e"] if $e;
 
         if (length($req_json) > 1000) {
-            $sock->syswrite("J" . length($req_json) . "\015\012");
-            $sock->syswrite($req_json);
-            $sock->syswrite("\015\012");
+            $sock->write("J" . length($req_json) . "\015\012");
+            $sock->write($req_json);
+            $sock->write("\015\012");
         } else {
-            $sock->syswrite("j$req_json\015\012");
+            $sock->write("j$req_json\015\012");
         }
         $log->tracef("Sent request to server: %s", $req_json);
 
@@ -168,7 +168,7 @@ Perinci::Access::TCP::Client - Riap::TCP client
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
